pub enum BuildMode {
    Build,
    Check,
}
The build mode to use for this sysroot.

Variants



Build

Do a full sysroot build. Suited for all purposes (like the regular sysroot), but only works for the host or for targets that have suitable development tools installed.



Check

Do a check-only sysroot build. This is only suited for check-only builds of crates, but on the plus side it works for arbitrary targets without having any special tools installed.

Implementations