pub enum BuildMode {
Build,
Check,
}
The build mode to use for this sysroot.
Do a full sysroot build. Suited for all purposes (like the regular sysroot), but only works
for the host or for targets that have suitable development tools installed.
Do a check-only sysroot build. This is only suited for check-only builds of crates, but on
the plus side it works for arbitrary targets without having any special tools installed.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.